Contributing as a user
######################

Users can contribute in a variety of ways, such as reporting bugs, requesting
new features, testing in-development features, starting discussions, answering
questions, and sharing their work with the community.

.. warning::

    Do not include any proprietary or sensitive information when reporting bugs
    or showcasing your work.

.. grid:: 1 1 3 3

    .. grid-item-card:: :fa:`bug` Report bugs
        :padding: 2 2 2 2
        :link: report-bugs
        :link-type: ref

        Found a bug? Report it here.

    .. grid-item-card:: :fa:`lightbulb` Request a new feature
        :padding: 2 2 2 2
        :link: request-a-new-feature
        :link-type: ref

        Got an idea for a new feature? Share it!

    .. grid-item-card:: :fa:`vial-circle-check` Test a new feature
        :padding: 2 2 2 2
        :link: test-a-new-feature
        :link-type: ref

        Anxious to try out a new feature? Here's how you can do it.

    .. grid-item-card:: :fa:`comment-dots` Answer questions
        :padding: 2 2 2 2
        :link: answer-questions
        :link-type: ref

        Help others by answering their questions.

    .. grid-item-card:: :fa:`bullhorn` Share your work
        :padding: 2 2 2 2
        :link: share-your-work
        :link-type: ref

        Share your work with the community.

.. _report-bugs:

Report bugs
===========

If you encounter a bug or an issue while using the project, please report it.
Your feedback helps to identify problems.

- Search the `Ansys Sphinx theme issues`_ to see if the issue has already been reported.

- Create a new issue if it hasn’t been reported.

  - Include a clear description of the problem.
  - Provide steps to reproduce the issue.
  - Mention the version of the project you're using.
  - Include screenshots or logs if possible.

.. _request-a-new-feature:

Request a new feature
=====================

Do you have an idea for a new feature or an improvement? Your suggestions are
welcome. You can request a new feature by creating an issue in the `Ansys sphinx theme issues`_
board.

.. _test-a-new-feature:

Test a new feature
==================

It is possible to test a new feature before it is officially released. To do
so, you can install Ansys Sphinx theme from the source code.

.. _answer-questions:

Answer questions
================

Another great way to contribute is to help others by answering their questions.
Maintain a positive and constructive attitude while answering questions. If you
don't know the answer, you can still help by pointing the person in the right
direction.

.. _share-your-work:

Share your work
===============

If you have used Ansys Sphinx theme to create something interesting, share it with the rest
of the community. You can share your work in the `Ansys Sphinx theme issues`_. Include
a brief description of your work and any relevant links that others may find
useful.